"use strict" ;

import baseAssignValue from './baseAssignValue'
import eq from '../eq'

const hasOwnProp = Object.prototype.hasOwnProperty;

/**
 * Assigns `value` to `key` of `object` if the existing value is not equivalent.
 * @private
 * @param {Object} object - The object to populate.
 * @param {string} key - The key of the property to assign.
 * @param {*} value - The value to assign.
 */
const assignValue = ( object, key, value ) =>
{
    const objValue = object[key] ;
    if ( !(hasOwnProp.call(object, key) && eq(objValue, value)) || (value === undefined && !(key in object) ) )
    {
        baseAssignValue( object , key , value );
    }
};
export default assignValue ;